aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/tsi
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/tsi')
-rw-r--r--src/core/tsi/alts_transport_security.cc (renamed from src/core/tsi/gts_transport_security.cc)26
-rw-r--r--src/core/tsi/alts_transport_security.h (renamed from src/core/tsi/gts_transport_security.h)14
2 files changed, 21 insertions, 19 deletions
diff --git a/src/core/tsi/gts_transport_security.cc b/src/core/tsi/alts_transport_security.cc
index 2b099773c4..ddd75cbd02 100644
--- a/src/core/tsi/gts_transport_security.cc
+++ b/src/core/tsi/alts_transport_security.cc
@@ -16,25 +16,27 @@
*
*/
-#include "src/core/tsi/gts_transport_security.h"
+#include "src/core/tsi/alts_transport_security.h"
#include <string.h>
-static gts_shared_resource g_gts_resource;
+static alts_shared_resource g_alts_resource;
-gts_shared_resource* gts_get_shared_resource(void) { return &g_gts_resource; }
+alts_shared_resource* alts_get_shared_resource(void) {
+ return &g_alts_resource;
+}
-void grpc_tsi_gts_init() {
- memset(&g_gts_resource, 0, sizeof(gts_shared_resource));
- gpr_mu_init(&g_gts_resource.mu);
+void grpc_tsi_alts_init() {
+ memset(&g_alts_resource, 0, sizeof(alts_shared_resource));
+ gpr_mu_init(&g_alts_resource.mu);
}
-void grpc_tsi_gts_shutdown() {
- gpr_mu_destroy(&g_gts_resource.mu);
- if (g_gts_resource.cq == nullptr) {
+void grpc_tsi_alts_shutdown() {
+ gpr_mu_destroy(&g_alts_resource.mu);
+ if (g_alts_resource.cq == nullptr) {
return;
}
- grpc_completion_queue_destroy(g_gts_resource.cq);
- grpc_channel_destroy(g_gts_resource.channel);
- gpr_thd_join(g_gts_resource.thread_id);
+ grpc_completion_queue_destroy(g_alts_resource.cq);
+ grpc_channel_destroy(g_alts_resource.channel);
+ gpr_thd_join(g_alts_resource.thread_id);
}
diff --git a/src/core/tsi/gts_transport_security.h b/src/core/tsi/alts_transport_security.h
index 23b2b66fb3..c90e31478e 100644
--- a/src/core/tsi/gts_transport_security.h
+++ b/src/core/tsi/alts_transport_security.h
@@ -16,22 +16,22 @@
*
*/
-#ifndef GRPC_CORE_TSI_GTS_TRANSPORT_SECURITY_H
-#define GRPC_CORE_TSI_GTS_TRANSPORT_SECURITY_H
+#ifndef GRPC_CORE_TSI_ALTS_TRANSPORT_SECURITY_H
+#define GRPC_CORE_TSI_ALTS_TRANSPORT_SECURITY_H
#include <grpc/grpc.h>
#include <grpc/support/sync.h>
#include <grpc/support/thd.h>
-typedef struct gts_shared_resource {
+typedef struct alts_shared_resource {
gpr_thd_id thread_id;
grpc_channel* channel;
grpc_completion_queue* cq;
gpr_mu mu;
-} gts_shared_resource;
+} alts_shared_resource;
-/* This method returns the address of gts_shared_resource object shared by all
+/* This method returns the address of alts_shared_resource object shared by all
* TSI handshakes. */
-gts_shared_resource* gts_get_shared_resource(void);
+alts_shared_resource* alts_get_shared_resource(void);
-#endif /* GRPC_CORE_TSI_GTS_TRANSPORT_SECURITY_H */
+#endif /* GRPC_CORE_TSI_ALTS_TRANSPORT_SECURITY_H */